Makes surface plots to display interactions between two continuous variables
DAintfun(obj, varnames, theta = 45, phi = 10, xlab=NULL, ylab=NULL, zlab=NULL,
hcols=NULL, ...)A model object of class lm
A two-element character vector where each element is the name of a variable involved in a two-way interaction.
Angle defining the azimuthal viewing direction to be passed to persp
Angle defining the colatitude viewing direction to be passed to persp
Optional label to put on the x-axis, otherwise if NULL, it will take the first element of varnames
Optional label to put on the y-axis, otherwise if NULL, it will take the second element of varnames
Optional label to put on the z-axis, otherwise if NULL, it will be ‘Predictions’
Vector of four colors to color increasingly high density areas
Other arguments to be passed down to the initial call to persp
Values of the first element of varnames used to make predictions.
Values of the second element of varnames used to make predictions.
The predictions based on the values x1 and x2.
A graph is produced, but no other information is returned.
This function makes a surface plot of an interaction between two continuous covariates. If the model is
$$y_{i} = b_{0} + b_{1}x_{i1} + b_{2}x_{i2} + b_{3}x_{i1}\times x_{i2} + \ldots + e_{i},$$
this function plots \(b_{1}x_{i1} + b_{2}x_{i2} + b_{3}x_{i1}\times x_{i2}\) for values over the range of \(X_{1}\) and \(X_{2}\). The highest 75%, 50% and 25% of the bivariate density of \(X_{1}\) and \(X_{2}\) (as calculated by sm.density from the sm package) are colored in with colors of increasing gray-scale.
# NOT RUN {
data(InteractionEx)
mod <- lm(y ~ x1*x2 + z, data=InteractionEx)
DAintfun(mod, c("x1", "x2"))
# }
Run the code above in your browser using DataLab