Learn R Programming

DAMisc (version 1.5)

panel.2cat: Lattice panel function for confidence intervals with capped bars

Description

This panel function is defined to plot confidence intervals in a multi-panel lattice display where the x-variable is categorical. Note, both lower and upper must be passed directly to xyplot as they will be passed down to the panel function.

Usage

panel.2cat(x,y,subscripts, lower,upper, length=.2)

Arguments

x,y

Data from the call to xyplot.

subscripts

Variable used to created the juxtaposed panels.

lower, upper

95% lower and upper bounds of y.

length

Length of the arrow head lines.

Examples

Run this code
# NOT RUN {
library(car)
library(lattice)
library(effects)
data(Duncan)
Duncan$inc.cat <- cut(Duncan$income, 3)
mod <- lm(prestige~ inc.cat * type + education,
  data=Duncan)
e1 <- effect("inc.cat*type", mod)
update(plot(e1), panel=panel.2cat)
# }

Run the code above in your browser using DataLab