Learn R Programming

DAMisc (version 1.5)

panel.transci: Lattice panel function for translucent confidence intervals

Description

This panel function is defined to plot translucent confidence intervals in a single-panel, grouped (i.e., superposed) lattice display. Note, both lower and upper must be passed directly to xyplot as they will be passed down to the panel function.

Usage

panel.transci(x,y,groups, lower,upper, ca=.25, ...)

Arguments

x,y

Data from the call to xyplot.

groups

Variable used to created the superposed panels.

lower, upper

95% lower and upper bounds of y.

ca

Value of the alpha channel in [0,1]

...

Other arguments to be passed down to the plotting functions.