Plots the optimally scaled points with posterior 95% credible intervals.
# S3 method for balsos
plot(x, ..., freq=TRUE, offset=.1)Object of class balsos.
Logical indicating whether you want the frequentist result plotted alongside the Bayesian result.
If freq=T, the Bayesian points will be plotted at x-offset and the frequentist points will be plotted at x+offset.
Other arguments to be passed down, currently not implement and may conflict with the lattice figure. To change the figure the best advice would be to save the plot as an oject and use the update function to change its features.
A lattice graph produce by a call to xyplot.