print.pre: Print method for objects of class pre
Description
Prints the output from an object of class pre. The function prints all components of the calculation and optionally simulated confidence bounds.
Usage
# S3 method for pre
print(x, ..., sim.ci=.95)
Arguments
sim.ci
Coverage for the simulated confidence interval, if sim=TRUE in the call to pre.
...
Other arguments passed to print, currently not implemented