Learn R Programming

DAMisc (version 1.5)

probgroup: Plog Probabilities by Group

Description

Plots predicted probabilities by value of the dependent variable for proportional odds logistic regression and multinomial logistic regression models

Usage

# S3 method for polr
probgroup(obj, ...)
    # S3 method for multinom
probgroup(obj, ...)

Arguments

obj

Object of class polr or multinom where appropraite.

...

Currently not implemented.

Value

A plot.

Details

Plots the predicted probabilities by value of the dependent variable. Each panel only includes the observations that had the identified value of the dependent variable.