Learn R Programming

DAMisc (version 1.5)

scaleDataFrame: Standardize quantitative variables in a data frame

Description

This function standardizes quantitative variables in a data frame while leaving the others untouched. This leaves not only factors, but also binary variables (those with values 0, 1, or NA).

Usage

scaleDataFrame(data)

Arguments

data

A data frame.

Value

A data frame with standardized quantitative variables