Learn R Programming

DAMisc (version 1.5)

secondDiff: Calculate Cross-Derivative and its Variability

Description

Calculates the cross-derivative required to evaluate interactions in logistic/probit regression models.

Usage

secondDiff(obj, vars, data, method=c("AME", "MER"), typical = NULL)

Arguments

obj

An object of class glm that will be used to find the cross-derivative.

vars

A vector of two variables to be used in calculating the derivative.

data

A data frame.

method

Indicate whether you want to use average marginal effects (AME) or marginal effects at representative values (MER).

typical

A named vector of values at which to hold variables constant.

Value

A data frame with standardized quantitative variables