Calculates predicted probabilities from models of class polr from a model object and a vector of coefficient values. This is an auxiliary function used in pre if sim=TRUE.
simPredpolr(object, coefs, n.coef)An object of class polr.
Number of coefficients (minus intercepts) for the polr model.
A vector of coefficients where elements 1 to n.coef give model coefficients and elements n.coef+1 to k have intercepts.
An n x m-category matrix of predicted probabilities