Learn R Programming

DAMisc (version 1.5)

testLoess: Significance Test for Loess vs. LM

Description

Calculates an F test to evaluate significant differences between a LOESS model and a parametric alternative estimated with lm

Usage

testLoess(lmobj, loessobj, alpha=.05)

Arguments

lmobj

An object of class lm.

loessobj

An object of class loess.

alpha

Desired Type I error rate of test.

Value

Printed output describing the results of the test.

Examples

Run this code
# NOT RUN {
library(car)
linmod <- lm(prestige ~ income, data=Prestige)
lomod <- loess(prestige ~ income, data=Prestige)
testLoess(linmod, lomod)
# }

Run the code above in your browser using DataLab