powered by
This function makes a table of fitted values and confidence intervals for all of the combinations of two categorical variables in an interaction.
cat2Table(eff.obj, digits, rownames=NULL, colnames=NULL)
An object generated by effect from the effects package where the effect is calculated for two factors involved in an interaction.
effect
effects
Number of digits of the fitted values and confidence intervals to print.
An optional vector of row names for the table, if NULL, the levels of the factor will be used
NULL
An optional vector of column names for the table, if NULL, the levels of the factor will be used
A matrix of fitted values and confidence intervals
# NOT RUN { library(car) data(Duncan) Duncan$inc.cat <- cut(Duncan$income, 3) mod <- lm(prestige ~ inc.cat*type + income, data=Duncan) e1 <- effect("inc.cat*type", mod) cat2Table(e1) # }
Run the code above in your browser using DataLab