Plots predicted probabilities by value of the dependent variable for proportional odds logistic regression and multinomial logistic regression models
# S3 method for polr
probgroup(obj, ...)
# S3 method for multinom
probgroup(obj, ...)Object of class polr or multinom where appropraite.
Currently not implemented.
A plot.
Plots the predicted probabilities by value of the dependent variable. Each panel only includes the observations that had the identified value of the dependent variable.