Calculates the cross-derivative required to evaluate interactions in logistic/probit regression models.
secondDiff(obj, vars, data, method=c("AME", "MER"), typical = NULL)An object of class glm that will be used to find the cross-derivative.
A vector of two variables to be used in calculating the derivative.
A data frame.
Indicate whether you want to use average marginal effects (AME) or marginal effects at representative values (MER).
A named vector of values at which to hold variables constant.
A data frame with standardized quantitative variables