powered by
Calculates an F test to evaluate significant differences between a LOESS model and a parametric alternative estimated with lm
lm
testLoess(lmobj, loessobj, alpha=.05)
An object of class lm.
An object of class loess.
loess
Desired Type I error rate of test.
Printed output describing the results of the test.
# NOT RUN { library(car) linmod <- lm(prestige ~ income, data=Prestige) lomod <- loess(prestige ~ income, data=Prestige) testLoess(linmod, lomod) # }
Run the code above in your browser using DataLab